@@ -47,6 +47,9 @@
 #    if defined(WINAPI_FAMILY_PHONE_APP) && (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP)
 #      define IUTEST_OS_WINDOWS_PHONE	1
 #      define IUTEST_PLATFORM			"Windows Phone"
+#    elif defined(WINAPI_FAMILY_APP) && (WINAPI_FAMILY == WINAPI_FAMILY_APP)
+#      define IUTEST_OS_WINDOWS_RT		1
+#      define IUTEST_PLATFORM			"Windows RT"
 #    else
 #      define IUTEST_OS_WINDOWS_DESKTOP	1
 #    endif
@@ -181,7 +184,7 @@
 #      define IUTEST_HAS_CONSTEXPR	0
 #    endif
 #  elif defined(_MSC_VER)
-#    if _MSC_FULL_VER == 180021114
+#    if _MSC_VER >= 1900 || _MSC_FULL_VER == 180021114
 #      define IUTEST_HAS_CONSTEXPR	1
 #    else
 #      define IUTEST_HAS_CONSTEXPR	0
@@ -201,7 +204,6 @@
 #  define IUTEST_CXX_CONSTEXPR			constexpr
 #  define IUTEST_CXX_CONSTEXPR_OR_CONST	constexpr
 #else
-#  define IUTEST_NO_CONSTEXPR
 #  define IUTEST_CXX_CONSTEXPR
 #  define IUTEST_CXX_CONSTEXPR_OR_CONST	const
 #endif
@@ -568,6 +570,9 @@
 #      define IUTEST_HAS_STRONG_ENUMS	1
 #    endif
 #  elif defined(_MSC_VER)
+#    if _MSC_VER >= 1700
+#      define IUTEST_HAS_STRONG_ENUMS	1
+#    endif
 #  endif
 #endif
 
@@ -679,7 +684,7 @@
 
 // explicit instantiation access checking
 #if !defined(IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_MEMBER_FUNCTION)
-#  if defined(_MSC_VER) && (_MSC_VER < 1600)
+#  if defined(_MSC_VER) && ((_MSC_VER < 1600) || (_MSC_VER == 1900))
      // VS2008 以前では、private なメンバー関数に explicit instantiation でもアクセスできない
 #    define IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_MEMBER_FUNCTION	0
 #  else
@@ -687,6 +692,7 @@
 #  endif
 #endif
 
+// explicit instantiation access checking (static member function)
 #if !defined(IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_STATIC_MEMBER_FUNCTION)
 #  if defined(_MSC_VER)
 // Visual Studio では、private な static メンバー関数に explicit instantiation でもアクセスできない
@@ -703,7 +709,7 @@
 #  endif
 #endif
 
-// has __COUNTER__
+//! has __COUNTER__
 #if !defined(IUTEST_HAS_COUNTER_MACRO)
 #  if   defined(_MSC_VER) && (_MSC_VER >= 1300)
 #    define IUTEST_HAS_COUNTER_MACRO		1
@@ -734,7 +740,7 @@
 #  endif
 #endif
 
-// explicit class member template specialization
+//! explicit class member template specialization
 #if !defined(IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION)
 #  if defined(_MSC_VER)
 #    define IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION	1
@@ -809,7 +815,7 @@
 #if !defined(IUTEST_HAS_WANT_SECURE_LIB)
 #  if defined(_MSC_VER)
 #    if defined(__STDC_WANT_SECURE_LIB__) && __STDC_WANT_SECURE_LIB__
-#      define IUTEST_HAS_WANT_SECURE_LIB		1
+#      define IUTEST_HAS_WANT_SECURE_LIB	1
 #    endif
 #  endif
 #endif
