@@ -41,6 +41,15 @@ protected:
 	::std::string m_name;
 };
 
+/**
+ * @brief	パラメータテストインスタンスベースクラス
+*/
+class IParamEachTestBase
+{
+public:
+	virtual ~IParamEachTestBase(void) {}
+};
+
 /**
  * @brief	パラメータ単体テストインスタンスインターフェイス
 */
