@@ -4,9 +4,7 @@
  * @file		iutest_random.hpp
  * @brief		iris unit test 乱数生成器 定義 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -36,7 +34,7 @@ namespace detail
 */
 class iuRandom
 {
-#if defined(IUTEST_USE_RANDOM_ENGINE_TYPENAME)
+#if IUTEST_HAS_CXX_HDR_RANDOM && defined(IUTEST_USE_RANDOM_ENGINE_TYPENAME)
 	typedef IUTEST_USE_RANDOM_ENGINE_TYPENAME Engine;
 #else
 	class Engine
@@ -116,7 +114,7 @@ public:
 	 * @brief	初期化
 	 * @details	時間でシードを決定
 	*/
-	void	init(void)
+	void init(void)
 	{
 		init(GetIndefiniteValue());
 	}
@@ -124,7 +122,7 @@ public:
 	 * @brief	初期化
 	 * @param [in]	seed	= シード
 	*/
-	void	init(unsigned int seed)
+	void init(unsigned int seed)
 	{
 		m_engine = Engine(seed);
 	}
@@ -159,7 +157,7 @@ public:
 	 * @details	[0,1] の乱数を生成
 	 * @return	乱数
 	*/
-	float				genrandf(void)
+	float genrandf(void)
 	{
 #if IUTEST_HAS_CXX_HDR_RANDOM
 		return ::std::uniform_real_distribution<float>(0.0f, 1.0f)(m_engine);
@@ -179,8 +177,8 @@ public:
 	}
 
 #if IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION && (defined(_MSC_VER) && _MSC_VER < 1300)
-	template<>float		genrand<float>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(float))	{ return genrandf(); }
-	template<>double	genrand<double>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(double))	{ return static_cast<double>(genrandf()); }
+	template<>float  genrand<float>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(float)) { return genrandf(); }
+	template<>double genrand<double>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(double)) { return static_cast<double>(genrandf()); }
 #endif
 
 public:
@@ -192,14 +190,25 @@ public:
 	{
 		return genrand(max);
 	}
+
+public:
+	template<typename It>
+	void shuffle(It first, It last)
+	{
+#if IUTEST_HAS_CXX_HDR_RANDOM
+		std::shuffle(first, last, m_engine);
+#else
+		std::random_shuffle(first, last, *this);
+#endif
+	}
 };
 
 #if !(defined(_MSC_VER) && _MSC_VER < 1300)
 
-template<> inline Int64		iuRandom::genrand<Int64>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(Int64))		{ return (static_cast<Int64>(genrand()) << 32) | genrand(); }
-template<> inline UInt64	iuRandom::genrand<UInt64>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(UInt64))	{ return (static_cast<UInt64>(genrand()) << 32) | genrand(); }
-template<> inline float		iuRandom::genrand<float>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(float))		{ return genrandf(); }
-template<> inline double	iuRandom::genrand<double>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(double))	{ return static_cast<double>(genrandf()); }
+template<> inline Int64  iuRandom::genrand<Int64>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(Int64))   { return (static_cast<Int64>(genrand()) << 32) | genrand(); }
+template<> inline UInt64 iuRandom::genrand<UInt64>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(UInt64)) { return (static_cast<UInt64>(genrand()) << 32) | genrand(); }
+template<> inline float  iuRandom::genrand<float>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(float))   { return genrandf(); }
+template<> inline double iuRandom::genrand<double>(IUTEST_EXPLICIT_TEMPLATE_TYPE_(double)) { return static_cast<double>(genrandf()); }
 
 #endif
 
@@ -239,4 +248,4 @@ private:
 }	// end of namespace detail
 }	// end of namespace iutest
 
-#endif	// INCG_IRIS_IUTEST_RANDOM_HPP_89F260D7_9145_4B50_A8F0_B7A2696121B6_
+#endif // INCG_IRIS_IUTEST_RANDOM_HPP_89F260D7_9145_4B50_A8F0_B7A2696121B6_
