@@ -17,10 +17,10 @@
 
 //======================================================================
 // define
-#define	IUTEST_VER			0x01090000u	//!< iutest version 1.9.0.0
+#define	IUTEST_VER			0x01090100u	//!< iutest version 1.9.1.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
 #define IUTEST_MINORVER		0x09u		//!< Minor Version
-#define IUTEST_BUILD		0x00u		//!< Build
+#define IUTEST_BUILD		0x01u		//!< Build
 #define IUTEST_REVISION		0x00u		//!< Revision
 
 /**
@@ -66,7 +66,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @par		Command Line Options
  <table>
    <tr><td>--help, -h                        </td><td></td><td>Generate help message.</td></tr>
-   <tr><td>--iutest_output                   </td><td>xml[:path]</td><td>Path of xml report.</td></tr>
+   <tr><td>--iutest_output                   </td><td>xml|junit[:path]</td><td>Path of xml report.</td></tr>
    <tr><td>--iutest_list_tests               </td><td></td><td>List up tests.</td></tr>
    <tr><td>--iutest_list_tests_with_where    </td><td></td><td>List up tests with where.</td></tr>
    <tr><td>--iutest_color                    </td><td>&lt;yes|no|auto|ansi&gt;</td><td>Console color enable.</td></tr>
@@ -91,7 +91,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	ENVIRONMENT_OPTIONS	環境変数オプション
  * @par		Environment variable Options
  <table>
-   <tr><td>IUTEST_OUTPUT=xml[:path]        </td><td>Path of xml report.</td></tr>
+   <tr><td>IUTEST_OUTPUT=xml|junit[:path]  </td><td>Path of xml report.</td></tr>
    <tr><td>IUTEST_COLOR=yes|no|auto        </td><td>Console color enable.</td></tr>
    <tr><td>IUTEST_FILTER=filter            </td><td>Select the test run.</td></tr>
    <tr><td>IUTEST_SHUFFLE                  </td><td>Do shuffle test.</td></tr>
@@ -110,6 +110,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	CHANGELOG		変更履歴
  * @par		Changes
  <ul>
+  <li>v1.9.1.0
+    <ul>
+      <li>IUTEST_P,IUTEST_TYPED_TEST_P で DISABLED_ 指定が機能しない問題を修正</li>
+      <li>TestFixutre を定義しなくても IUTEST_P が使えるように対応</li>
+      <li>Visual Studio 14 CTP 対応</li>
+    </ul>
+  </li>
   <li>v1.9.0.0
     <ul>
       <li>IUTEST_*_THAT 追加</li>
