@@ -4,9 +4,7 @@
  * @file		iutest_param_direct_tests.hpp
  * @brief		iris unit test initializer_list を使用したパラメータ設定 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2013-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -51,7 +49,7 @@
 		s_##prefix_##_##testcase_##_EvalGenerator_(void) {									\
 			return IUTEST_CAST_TO_PARAM_GENERATOR_(testcase_::ParamType, __VA_ARGS__); }	\
 		int s_##prefix_##_##testcase_##_dummy =												\
-			IIUT_GETTESTCASEPATTERNHOLDER(testcase_, IUTEST_TO_NAME_STR_(testcase_), IUTEST_GET_PACKAGENAME_())		\
+			IIUT_GETTESTCASEPATTERNHOLDER(testcase_, IIUT_TO_NAME_STR_(testcase_), IUTEST_GET_PACKAGENAME_())		\
 				->AddTestCaseInstantiation(#prefix_, s_##prefix_##_##testcase_##_EvalGenerator_)
 
 
