@@ -4,9 +4,7 @@
  * @file		iutest_assertion_only_tests.cpp
  * @brief		iutest assertion only test
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -65,8 +63,8 @@ int main(int, char**)
 {
 	IUTEST_EXPECT_EQ(0, 1);
 
-#ifndef IUTEST_USE_GTEST
-	::std::cout << s_outstream.str();
+#if !defined(IUTEST_USE_GTEST)
+//	::std::cout << s_outstream.str();
 	if( s_outstream.str().empty() ) return 1;
 #endif
 	::std::cout << "*** Successful ***" << ::std::endl;
