@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_break_on_fialure_tests.cpp
- * @brief		break_on_fialure ΉeXg
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		break_on_fialure 対応テスト
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -44,7 +42,7 @@ int main(int argc, char* argv[])
 {
 	::iutest::IUTEST_FLAG(break_on_failure) = true;
 	
-#if IUTEST_OS_WINDOWS
+#if defined(IUTEST_OS_WINDOWS) && IUTEST_OS_WINDOWS
 	SetErrorMode(SEM_NOGPFAULTERRORBOX | SEM_FAILCRITICALERRORS);
 #if IUTEST_HAS_SEH && !defined(IUTEST_OS_WINDOWS_MOBILE)
 	SetUnhandledExceptionFilter(ExitWithExceptionCode);
@@ -52,5 +50,5 @@ int main(int argc, char* argv[])
 #endif
 	
 	IUTEST_INIT(&argc, argv);
-	return IUTEST_RUN_ALL_TESTS();	// run all
+	return IUTEST_RUN_ALL_TESTS();
 }
