@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_catch_exceptions_tests.cpp
- * @brief		catch_exceptions ΉeXg
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		catch_exceptions 対応テスト
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -45,9 +43,9 @@ int main(int argc, char* argv[])
 	::iutest::IUTEST_FLAG(catch_exceptions) = false;
 
 #if IUTEST_HAS_EXCEPTIONS
-	::std::set_terminate(&TerminateHandler);	
+	::std::set_terminate(&TerminateHandler);
 #endif
 
 	IUTEST_INIT(&argc, argv);
-	return IUTEST_RUN_ALL_TESTS();	// run all
+	return IUTEST_RUN_ALL_TESTS();
 }
