@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_no_test_tests.cpp
- * @brief		eXgƂ̌ ΉeXg
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		テストが無いときの結果 対応テスト
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -30,17 +28,17 @@ int main(int argc, char* argv[])
 	IUTEST_EXPECT_EQ(0, 1);
 
 	{
-		int ret = IUTEST_RUN_ALL_TESTS();
+		const int ret = IUTEST_RUN_ALL_TESTS();
 		if( ret == 0 ) return 1;
 	}
 	{
-		int ret = IUTEST_RUN_ALL_TESTS();
+		const int ret = IUTEST_RUN_ALL_TESTS();
 		if( ret == 0 ) return 1;
 	}
 #if !defined(IUTEST_USE_GTEST)
 	{
 		IUTEST_INIT(&argc, argv);
-		int ret = IUTEST_RUN_ALL_TESTS();
+		const int ret = IUTEST_RUN_ALL_TESTS();
 		if( ret != 0 ) return 1;
 	}
 #endif
