@@ -2,11 +2,9 @@
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_param_test_tests.hpp
- * @brief		iutest parameter test
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		parameter test
  *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -14,8 +12,8 @@
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_iutest_param_test_tests_HPP_
-#define INCG_iutest_param_test_tests_HPP_
+#ifndef INCG_IUTEST_PARAM_TEST_TESTS_HPP_
+#define INCG_IUTEST_PARAM_TEST_TESTS_HPP_
 
 //======================================================================
 // include
