@@ -180,6 +180,11 @@ IUTEST(PrintToTest, WideString)
 		wchar_t c = 0;
 		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
 	}
+	{
+		LogChecker ck("10");
+		wchar_t c = L'\n';
+		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+	}
 //	{
 //		LogChecker ck("\'A\'");
 //		wchar_t c = L'A';
@@ -203,6 +208,11 @@ IUTEST(PrintToTest, String)
 		char c = 0;
 		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
 	}
+	{
+		LogChecker ck("10");
+		char c = '\n';
+		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+	}
 	{
 		LogChecker ck("\'A\'");
 		char c = 'A';
