@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_uninitialize_tests.cpp
- * @brief		filter ΉeXg
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		未初期化テスト
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -19,8 +17,6 @@
 // include
 #include "../include/iutest.hpp"
 
-#include <assert.h>
-
 IUTEST(Test, Dummy)
 {
 }
